@@ -915,7 +915,45 @@ def cluster_view(scheduler, queue, num_jobs, cores_per_job=1, profile=None,
             time.sleep(delay)
             slept += delay
             if slept > max_delay:
-                raise IOError("Cluster startup timed out.")
+                raise IOError("""
+
+    The cluster startup timed out. This could be for a couple of reasons. The
+    most common reason is that the queue you are submitting jobs to is
+    oversubscribed. You can check if this is what is happening by trying again,
+    and watching to see if jobs are in a pending state or a running state when
+    the startup times out. If they are in the pending state, that means we just
+    need to wait longer for them to start, which you can specify by passing
+    the --timeout parameter, in minutes.
+
+    The second reason is that there is a problem with the controller and engine
+    jobs being submitted to the scheduler. In the directory you ran from,
+    you should see files that are named YourScheduler_enginesABunchOfNumbers and
+    YourScheduler_controllerABunchOfNumbers. If you submit one of those files
+    manually to your scheduler (for example bsub < YourScheduler_controllerABunchOfNumbers)
+    You will get a more helpful error message that might help you figure out what
+    is going wrong.
+
+    The third reason is that you need to submit your bcbio_nextgen.py job itself as a job;
+    bcbio-nextgen needs to run on a compute node, not the login node. So the
+    command you use to run bcbio-nextgen should be submitted as a job to
+    the scheduler. You can diagnose this because the controller and engine
+    jobs will be in the running state, but the cluster will still timeout.
+
+    Finally, it may be an issue with how the cluster is configured-- the controller
+    and engine jobs are unable to talk to each other. They need to be able to open
+    ports on the machines each of them are running on in order to work. You
+    can diagnose this as the possible issue by if you have submitted the bcbio-nextgen
+    job to the scheduler, the bcbio-nextgen main job and the controller and
+    engine jobs are all in a running state and the cluster still times out. This will
+    likely to be something that you'll have to talk to the administrators of the cluster
+    you are using about.
+
+    If you need help debugging, please post an issue here and we'll try to help you
+    with the detective work:
+
+    https://github.com/roryk/ipython-cluster-helper/issues
+
+                        """)
         client = Client(url_file, timeout=60)
         if direct:
             view = _get_direct_view(client, retries)
